@@ -46,7 +46,7 @@ class ParameterGenerator extends AbstractGenerator
         if (! $variadic && ($reflectionParameter->isOptional() || $reflectionParameter->isDefaultValueAvailable())) {
             try {
                 $param->setDefaultValue($reflectionParameter->getDefaultValue());
-            } catch (ReflectionException $e) {
+            } catch (ReflectionException) {
                 $param->setDefaultValue(null);
             }
         }
@@ -72,7 +72,6 @@ class ParameterGenerator extends AbstractGenerator
      * @configkey sourcecontent         string
      * @configkey omitdefaultvalue      bool
      * @throws Exception\InvalidArgumentException
-     * @param  array $array
      * @return ParameterGenerator
      */
     public static function fromArray(array $array)
