@@ -16,6 +16,8 @@ use LaminasTest\Code\Generator\TestAsset\ClassWithDnfTypes;
 use LaminasTest\Code\Generator\TestAsset\ClassWithPromotedParameter;
 use LaminasTest\Code\Generator\TestAsset\ReadonlyClassWithPromotedParameter;
 use LaminasTest\Code\TestAsset\FooClass;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\RequiresPhp;
 use PHPUnit\Framework\TestCase;
 use ReflectionMethod;
 use Serializable;
@@ -27,10 +29,8 @@ use function fclose;
 use function fopen;
 use function key;
 
-/**
- * @group Laminas_Code_Generator
- * @group Laminas_Code_Generator_Php
- */
+#[Group('Laminas_Code_Generator')]
+#[Group('Laminas_Code_Generator_Php')]
 class ClassGeneratorTest extends TestCase
 {
     public function testConstruction(): void
@@ -201,9 +201,7 @@ class ClassGeneratorTest extends TestCase
         $classGenerator->addMethodFromGenerator($methodB);
     }
 
-    /**
-     * @group Laminas-7361
-     */
+    #[Group('Laminas-7361')]
     public function testHasMethod(): void
     {
         $classGenerator = new ClassGenerator();
@@ -222,9 +220,7 @@ class ClassGeneratorTest extends TestCase
         self::assertFalse($classGenerator->hasMethod('methodOne'));
     }
 
-    /**
-     * @group Laminas-7361
-     */
+    #[Group('Laminas-7361')]
     public function testHasProperty(): void
     {
         $classGenerator = new ClassGenerator();
@@ -277,9 +273,7 @@ EOS;
         self::assertSame($expectedOutput, $output, $output);
     }
 
-    /**
-     * @group Laminas-7909
-     */
+    #[Group('Laminas-7909')]
     public function testClassFromReflectionThatImplementsInterfaces(): void
     {
         $reflClass = new ClassReflection(TestAsset\ClassWithInterface::class);
@@ -295,9 +289,7 @@ EOS;
         self::assertStringContainsString($expectedClassDef, $code);
     }
 
-    /**
-     * @group Laminas-7909
-     */
+    #[Group('Laminas-7909')]
     public function testClassFromReflectionDiscardParentImplementedInterfaces(): void
     {
         $reflClass = new ClassReflection(TestAsset\NewClassWithInterface::class);
@@ -313,9 +305,7 @@ EOS;
         self::assertStringContainsString($expectedClassDef, $code);
     }
 
-    /**
-     * @group 4988
-     */
+    #[Group('4988')]
     public function testNonNamespaceClassReturnsAllMethods(): void
     {
         require_once __DIR__ . '/../TestAsset/NonNamespaceClass.php';
@@ -325,9 +315,7 @@ EOS;
         self::assertCount(1, $classGenerator->getMethods());
     }
 
-    /**
-     * @group Laminas-9602
-     */
+    #[Group('Laminas-9602')]
     public function testSetextendedclassShouldIgnoreEmptyClassnameOnGenerate(): void
     {
         $classGeneratorClass = new ClassGenerator();
@@ -344,9 +332,7 @@ CODE;
         self::assertSame($expected, $classGeneratorClass->generate());
     }
 
-    /**
-     * @group Laminas-9602
-     */
+    #[Group('Laminas-9602')]
     public function testSetextendedclassShouldNotIgnoreNonEmptyClassnameOnGenerate(): void
     {
         $classGeneratorClass = new ClassGenerator();
@@ -363,9 +349,7 @@ CODE;
         self::assertSame($expected, $classGeneratorClass->generate());
     }
 
-    /**
-     * @group namespace
-     */
+    #[Group('namespace')]
     public function testCodeGenerationShouldTakeIntoAccountNamespacesFromReflection(): void
     {
         $reflClass      = new ClassReflection(TestAsset\ClassWithNamespace::class);
@@ -384,9 +368,7 @@ CODE;
         self::assertSame($expected, $received, $received);
     }
 
-    /**
-     * @group namespace
-     */
+    #[Group('namespace')]
     public function testSetNameShouldDetermineIfNamespaceSegmentIsPresent(): void
     {
         $classGeneratorClass = new ClassGenerator();
@@ -394,9 +376,7 @@ CODE;
         self::assertSame('My\Namespaced', $classGeneratorClass->getNamespaceName());
     }
 
-    /**
-     * @group namespace
-     */
+    #[Group('namespace')]
     public function testPassingANamespacedClassnameShouldGenerateANamespaceDeclaration(): void
     {
         $classGeneratorClass = new ClassGenerator();
@@ -405,9 +385,7 @@ CODE;
         self::assertStringContainsString('namespace My\Namespaced;', $received, $received);
     }
 
-    /**
-     * @group namespace
-     */
+    #[Group('namespace')]
     public function testPassingANamespacedClassnameShouldGenerateAClassnameWithoutItsNamespace(): void
     {
         $classGeneratorClass = new ClassGenerator();
@@ -458,9 +436,7 @@ CODE;
         self::assertFalse($classGenerator->hasUseAlias('My\First\Use\Class'));
     }
 
-    /**
-     * @group Laminas-151
-     */
+    #[Group('Laminas-151')]
     public function testAddUses(): void
     {
         $classGenerator = new ClassGenerator();
@@ -473,9 +449,7 @@ CODE;
         self::assertStringContainsString('use My\Second\Use\Class as MyAlias;', $generated);
     }
 
-    /**
-     * @group 4990
-     */
+    #[Group('4990')]
     public function testAddOneUseTwiceOnlyAddsOne(): void
     {
         $classGenerator = new ClassGenerator();
@@ -489,9 +463,7 @@ CODE;
         self::assertStringContainsString('use My\First\Use\Class;', $generated);
     }
 
-    /**
-     * @group 4990
-     */
+    #[Group('4990')]
     public function testAddOneUseWithAliasTwiceOnlyAddsOne(): void
     {
         $classGenerator = new ClassGenerator();
@@ -580,9 +552,7 @@ CODE;
         self::assertSame($expected, $output);
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testCanAddConstant(): void
     {
         $classGenerator = new ClassGenerator();
@@ -602,9 +572,7 @@ CODE;
         self::assertSame('value', $defaultValue->getValue());
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testCanAddConstantsWithArrayOfGenerators(): void
     {
         $classGenerator = new ClassGenerator();
@@ -624,9 +592,7 @@ CODE;
         self::assertSame('value2', $valueY->getValue());
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testCanAddConstantsWithArrayOfKeyValues(): void
     {
         $classGenerator = new ClassGenerator();
@@ -647,9 +613,7 @@ CODE;
         self::assertSame('value2', $valueY->getValue());
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testAddConstantThrowsExceptionWithInvalidName(): void
     {
         $classGenerator = new ClassGenerator();
@@ -725,7 +689,7 @@ CODE;
             $classGenerator->addConstant('a', $resource);
 
             $this->fail('Not supposed to be reached');
-        } catch (InvalidArgumentException $e) {
+        } catch (InvalidArgumentException) {
             self::assertEmpty($classGenerator->getConstants());
         } finally {
             fclose($resource);
@@ -740,9 +704,7 @@ CODE;
         $classGenerator->addConstant('a', [new stdClass()]);
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testAddConstantThrowsExceptionOnDuplicate(): void
     {
         $classGenerator = new ClassGenerator();
@@ -762,9 +724,7 @@ CODE;
         self::assertFalse($classGenerator->hasConstant('constantOne'));
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testAddPropertyIsBackwardsCompatibleWithConstants(): void
     {
         $classGenerator = new ClassGenerator();
@@ -776,9 +736,7 @@ CODE;
         self::assertSame('value1', $valueX->getValue());
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testAddPropertiesIsBackwardsCompatibleWithConstants(): void
     {
         $constants      = [
@@ -799,9 +757,7 @@ CODE;
         self::assertSame('value2', $valueY->getValue());
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testConstantsAddedFromReflection(): void
     {
         $reflector      = new ClassReflection(TestAsset\TestClassWithManyProperties::class);
@@ -813,9 +769,7 @@ CODE;
         self::assertSame('foo', $constantValue->getValue());
     }
 
-    /**
-     * @group 6274
-     */
+    #[Group('6274')]
     public function testClassCanBeGeneratedWithConstantAndPropertyWithSameName(): void
     {
         $reflector      = new ClassReflection(TestAsset\TestSampleSingleClass::class);
@@ -863,9 +817,7 @@ CODE;
         self::assertSame($contents, $classGenerator->generate());
     }
 
-    /**
-     * @group 6253
-     */
+    #[Group('6253')]
     public function testHereDoc(): void
     {
         $reflector      = new ClassReflection(TestAsset\TestClassWithHeredoc::class);
@@ -1128,9 +1080,7 @@ CODE;
         self::assertCount(0, $overrides);
     }
 
-    /**
-     * @group generate
-     */
+    #[Group('generate')]
     public function testUseTraitGeneration(): void
     {
         $classGenerator = new ClassGenerator();
@@ -1149,9 +1099,7 @@ CODE;
         self::assertSame($output, $classGenerator->generate());
     }
 
-    /**
-     * @group generate
-     */
+    #[Group('generate')]
     public function testTraitGenerationWithAliasesAndOverrides(): void
     {
         $classGenerator = new ClassGenerator();
@@ -1222,9 +1170,7 @@ EOS;
         self::assertStringContainsString('class ClassName extends FooClass', $classGenerator->generate());
     }
 
-    /**
-     * @group 75
-     */
+    #[Group('75')]
     public function testCorrectlyExtendsFullyQualifiedParentClass(): void
     {
         $classGenerator = new ClassGenerator();
@@ -1234,9 +1180,7 @@ EOS;
         self::assertStringContainsString('class ClassName extends \DateTime', $classGenerator->generate());
     }
 
-    /**
-     * @group 75
-     */
+    #[Group('75')]
     public function testCorrectlyExtendsRelativeParentClass(): void
     {
         $classGenerator = new ClassGenerator();
@@ -1245,9 +1189,7 @@ EOS;
         self::assertStringContainsString('class ClassName extends DateTime', $classGenerator->generate());
     }
 
-    /**
-     * @group 75
-     */
+    #[Group('75')]
     public function testCorrectExtendNamesFromGlobalNamespace(): void
     {
         $classGenerator = new ClassGenerator();
@@ -1335,7 +1277,6 @@ EOS;
         self::assertStringContainsString($expected, $classGenerator->generate());
     }
 
-    /** @requires PHP >= 8.1 */
     public function testFinalConstantsAddedFromReflection(): void
     {
         $reflector      = new ClassReflection(TestAsset\ClassWithFinalConst::class);
@@ -1378,7 +1319,6 @@ EOS;
         self::assertSame($expectedOutput, $output, $output);
     }
 
-    /** @requires PHP >= 8.0 */
     public function testGenerateClassWithPromotedConstructorParameter(): void
     {
         $classGenerator = new ClassGenerator();
@@ -1405,7 +1345,6 @@ EOS;
         self::assertEquals($expectedOutput, $classGenerator->generate());
     }
 
-    /** @requires PHP >= 8.0 */
     public function testClassWithPromotedParameterFromReflection(): void
     {
         $classGenerator = ClassGenerator::fromReflection(
@@ -1427,7 +1366,6 @@ EOS;
         self::assertEquals($expectedOutput, $classGenerator->generate());
     }
 
-    /** @requires PHP >= 8.0 */
     public function testFailToGenerateClassWithPromotedParameterOnNonConstructorMethod(): void
     {
         $classGenerator = new ClassGenerator();
@@ -1442,7 +1380,7 @@ EOS;
         ]);
     }
 
-    /** @requires PHP >= 8.2 */
+    #[RequiresPhp('>= 8.2')]
     public function testReadonlyClassWithPromotedParameterFromReflection(): void
     {
         $classGenerator = ClassGenerator::fromReflection(
@@ -1464,7 +1402,7 @@ EOS;
         self::assertEquals($expectedOutput, $classGenerator->generate());
     }
 
-    /** @requires PHP >= 8.2 */
+    #[RequiresPhp('>= 8.2')]
     public function testDnfClass(): void
     {
         $classGenerator = ClassGenerator::fromReflection(
