@@ -17,6 +17,8 @@ use LaminasTest\Code\TestAsset\NullableReturnTypeHintedClass;
 use LaminasTest\Code\TestAsset\ObjectHintsClass;
 use LaminasTest\Code\TestAsset\Php80Types;
 use LaminasTest\Code\TestAsset\ReturnTypeHintedClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\TestCase;
 use stdClass;
 
@@ -25,10 +27,8 @@ use function array_map;
 use function array_shift;
 use function array_values;
 
-/**
- * @group Laminas_Code_Generator
- * @group Laminas_Code_Generator_Php
- */
+#[Group('Laminas_Code_Generator')]
+#[Group('Laminas_Code_Generator_Php')]
 class MethodGeneratorTest extends TestCase
 {
     public function testMethodConstructor()
@@ -135,7 +135,6 @@ EOS;
         self::assertSame($target, (string) $methodGenerator);
     }
 
-    /** @requires PHP >= 8.0 */
     public function testCopyMethodSignatureForPromotedParameter(): void
     {
         $ref = new MethodReflection(TestAsset\ClassWithPromotedParameter::class, '__construct');
@@ -194,9 +193,7 @@ EOS;
         self::assertSame($target, (string) $methodGenerator);
     }
 
-    /**
-     * @group Laminas-6444
-     */
+    #[Group('Laminas-6444')]
     public function testMethodWithStaticModifierIsEmitted()
     {
         $methodGenerator = new MethodGenerator();
@@ -214,9 +211,7 @@ EOS;
         self::assertSame($expected, $methodGenerator->generate());
     }
 
-    /**
-     * @group Laminas-6444
-     */
+    #[Group('Laminas-6444')]
     public function testMethodWithFinalModifierIsEmitted()
     {
         $methodGenerator = new MethodGenerator();
@@ -233,9 +228,7 @@ EOS;
         self::assertSame($expected, $methodGenerator->generate());
     }
 
-    /**
-     * @group Laminas-6444
-     */
+    #[Group('Laminas-6444')]
     public function testMethodWithFinalModifierIsNotEmittedWhenMethodIsAbstract()
     {
         $methodGenerator = new MethodGenerator();
@@ -250,9 +243,7 @@ EOS;
         self::assertSame($expected, $methodGenerator->generate());
     }
 
-    /**
-     * @group Laminas-7205
-     */
+    #[Group('Laminas-7205')]
     public function testMethodCanHaveDocBlock()
     {
         $methodGeneratorProperty = new MethodGenerator(
@@ -275,9 +266,7 @@ EOS;
         self::assertSame($expected, $methodGeneratorProperty->generate());
     }
 
-    /**
-     * @group Laminas-7268
-     */
+    #[Group('Laminas-7268')]
     public function testDefaultValueGenerationDoesNotIncludeTrailingSemicolon()
     {
         $method  = new MethodGenerator('setOptions');
@@ -319,11 +308,10 @@ EOS;
     }
 
     /**
-     * @dataProvider returnsReferenceValues
-     * @param bool|string|int $value
      * @param bool $expected
      */
-    public function testCreateFromArrayWithReturnsReference($value, $expected): void
+    #[DataProvider('returnsReferenceValues')]
+    public function testCreateFromArrayWithReturnsReference(bool|string|int $value, $expected): void
     {
         $methodGenerator = MethodGenerator::fromArray([
             'name'             => 'SampleMethod',
@@ -376,9 +364,7 @@ CODE;
         self::assertInstanceOf(DocBlockGenerator::class, $methodGenerator->getDocBlock());
     }
 
-    /**
-     * @group zendframework/zend-code#29
-     */
+    #[Group('zendframework/zend-code#29')]
     public function testSetReturnType()
     {
         $methodGenerator = new MethodGenerator();
@@ -395,9 +381,7 @@ PHP;
         self::assertSame($expected, $methodGenerator->generate());
     }
 
-    /**
-     * @group zendframework/zend-code#29
-     */
+    #[Group('zendframework/zend-code#29')]
     public function testSetReturnTypeWithNull()
     {
         $methodGenerator = new MethodGenerator();
@@ -415,12 +399,12 @@ PHP;
     }
 
     /**
-     * @group zendframework/zend-code#29
-     * @dataProvider returnTypeHintClasses
      * @param string $className
      * @param string $methodName
      * @param string $expectedReturnSignature
      */
+    #[DataProvider('returnTypeHintClasses')]
+    #[Group('zendframework/zend-code#29')]
     public function testFrom($className, $methodName, $expectedReturnSignature)
     {
         $methodGenerator = MethodGenerator::fromReflection(new MethodReflection($className, $methodName));
@@ -470,9 +454,7 @@ PHP;
         ];
     }
 
-    /**
-     * @group zendframework/zend-code#29
-     */
+    #[Group('zendframework/zend-code#29')]
     public function testByRefReturnType()
     {
         $methodGenerator = new MethodGenerator('foo');
@@ -486,9 +468,7 @@ PHP;
         self::assertStringMatchesFormat('%Apublic function foo()%A', $methodGenerator->generate());
     }
 
-    /**
-     * @group zendframework/zend-code#29
-     */
+    #[Group('zendframework/zend-code#29')]
     public function testFromByReferenceMethodReflection()
     {
         $methodGenerator = MethodGenerator::fromReflection(
@@ -499,13 +479,12 @@ PHP;
     }
 
     /**
-     * @requires PHP >= 8.0
-     * @group laminas/laminas-code#53
-     * @dataProvider php80Methods
      * @psalm-param class-string $className
      * @psalm-param non-empty-string $method
      * @psalm-param non-empty-string $expectedGeneratedSignature
      */
+    #[DataProvider('php80Methods')]
+    #[Group('laminas/laminas-code#53')]
     public function testGeneratedReturnTypeForPhp80ReturnType(
         string $className,
         string $method,
